WalletApp class

Constructors

WalletApp({required String name, required String bridgeUrl, required String image, required String aboutUrl, String? universalUrl})
const
WalletApp.fromMap(Map<String, dynamic> json)
factory

Properties

aboutUrl → String
final
bridgeUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
image → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
universalUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited